@@ -743,11 +743,12 @@ impl Individual {
 
         let keys = self.obj.resources.keys();
 
+        let mut counter_a = 0;
         for predicate in keys {
             if ignore_predicates.contains(&predicate.as_str()) {
                 continue;
             }
-
+            counter_a += 1;
             let a_value = self.obj.resources.get(predicate.as_str());
             let b_value = b.obj.resources.get(predicate.as_str());
 
@@ -757,6 +758,22 @@ impl Individual {
             }
         }
 
+        let mut counter_b = 0;
+        for predicate in b.obj.resources.keys() {
+            if ignore_predicates.contains(&predicate.as_str()) {
+                continue;
+            }
+            counter_b += 1;
+
+            if counter_b > counter_a {
+                return false;
+            }
+        }
+
+        if counter_a != counter_b {
+            return false;
+        }
+
         true
     }
 }
