@@ -4,14 +4,14 @@ use crate::msgpack2individual::*;
 
 #[derive(PartialEq, Debug)]
 pub enum RawType {
-    CBOR,
-    JSON,
-    MSGPACK,
-    UNKNOWN,
+    Cbor,
+    Json,
+    Msgpack,
+    Unknown,
 }
 
 pub fn parse_to_predicate(expect_predicate: &str, iraw: &mut Individual) -> bool {
-    if iraw.raw.raw_type == RawType::MSGPACK {
+    if iraw.raw.raw_type == RawType::Msgpack {
         if let Err(e) = parse_msgpack_to_predicate(expect_predicate, iraw) {
             if !e.is_empty() {
                 error!("parse for [{}], err={}", expect_predicate, e);
@@ -19,7 +19,7 @@ pub fn parse_to_predicate(expect_predicate: &str, iraw: &mut Individual) -> bool
             return false;
         }
         return true;
-    } else if iraw.raw.raw_type == RawType::CBOR {
+    } else if iraw.raw.raw_type == RawType::Cbor {
         return parse_cbor_to_predicate(expect_predicate, iraw);
     }
 
@@ -36,14 +36,14 @@ pub fn parse_raw(iraw: &mut Individual) -> Result<(), i8> {
     let traw: &[u8] = iraw.raw.data.as_slice();
 
     if traw[0] == MSGPACK_MAGIC_HEADER {
-        iraw.raw.raw_type = RawType::MSGPACK;
+        iraw.raw.raw_type = RawType::Msgpack;
     } else {
-        iraw.raw.raw_type = RawType::CBOR;
+        iraw.raw.raw_type = RawType::Cbor;
     }
 
-    let res = if iraw.raw.raw_type == RawType::MSGPACK {
+    let res = if iraw.raw.raw_type == RawType::Msgpack {
         parse_msgpack(&mut iraw.raw)
-    } else if iraw.raw.raw_type == RawType::CBOR {
+    } else if iraw.raw.raw_type == RawType::Cbor {
         parse_cbor(&mut iraw.raw)
     } else {
         Err(-1)
